package com.ruoyi.bst.creditUser.mapper;

import java.math.BigDecimal;
import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.bst.creditUser.domain.CreditUser;
import com.ruoyi.bst.creditUser.domain.CreditUserQuery;
import com.ruoyi.bst.creditUser.domain.CreditUserVO;

/**
 * 挂账用户Mapper接口
 *
 * @author ruoyi
 * @date 2025-05-28
 */
public interface CreditUserMapper
{
    /**
     * 查询挂账用户
     *
     * @param id 挂账用户主键
     * @return 挂账用户
     */
    CreditUserVO selectCreditUserById(Long id);

    /**
     * 查询挂账用户列表
     *
     * @param query 挂账用户
     * @return 挂账用户集合
     */
    List<CreditUserVO> selectCreditUserList(@Param("query")CreditUserQuery query);

    /**
     * 新增挂账用户
     *
     * @param creditUser 挂账用户
     * @return 结果
     */
    int insertCreditUser(CreditUser creditUser);

    /**
     * 修改挂账用户
     *
     * @param creditUser 挂账用户
     * @return 结果
     */
    public int updateCreditUser(@Param("data") CreditUser creditUser);

    /**
     * 删除挂账用户
     *
     * @param id 挂账用户主键
     * @return 结果
     */
    int deleteCreditUserById(Long id);

    /**
     * 批量删除挂账用户
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCreditUserByIds(@Param("ids") List<Long> ids);

    /**
     * 查询id列表
     *
     * @param query 查询条件
     * @return id列表
     */
    List<Long> selectIdList(@Param("query") CreditUserQuery query);

    /**
     * 增加使用金额
     * @param id id
     * @param amount 金额
     * @return
     */
    int addUsedAmount(@Param("id") Long id, @Param("amount") BigDecimal amount);

    /**
     * 查询数量
     * @param query 查询条件
     * @return 数量
     */
    int selectCount(@Param("query") CreditUserQuery query);
}
